'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _jschannel = require('jschannel');

var _jschannel2 = _interopRequireDefault(_jschannel);

var _eventemitter = require('eventemitter3');

var _eventemitter2 = _interopRequireDefault(_eventemitter);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var KioskClient = function () {
  function KioskClient(kioskFrame) {
    var _this = this;

    _classCallCheck(this, KioskClient);

    this.downloadProgress = function (context, _ref) {
      var url = _ref.url;
      var progress = _ref.progress;

      var emitter = _this.emitters[url];
      emitter.emit('progress', progress);
    };

    this.downloadCompleted = function (context, _ref2) {
      var url = _ref2.url;
      var localUrl = _ref2.localUrl;

      var emitter = _this.emitters[url];
      emitter.emit('end', localUrl);
      // download is done, delete emitter so that it's recreated for the next request
      _this.emitters[url] = null;
    };

    this.downloadError = function (context, _ref3) {
      var url = _ref3.url;
      var error = _ref3.error;

      var emitter = _this.emitters[url];
      emitter.emit('error', error);
      // download errored, delete emitter so that it's recreated for the next request
      _this.emitters[url] = null;
    };

    this.channel = _jschannel2.default.build({
      window: kioskFrame,
      origin: '*',
      scope: 'kiosk'
    });

    this.emitters = {};

    this.channel.bind('downloadProgress', this.downloadProgress);
    this.channel.bind('downloadCompleted', this.downloadCompleted);
    this.channel.bind('downloadError', this.downloadError);
  }

  _createClass(KioskClient, [{
    key: 'cache',
    value: function cache(url) {
      var emitter = this.emitters[url];

      if (!emitter) {
        emitter = new _eventemitter2.default();
        this.emitters[url] = emitter;
      }

      this.channel.notify({ method: 'cache', params: url });

      return emitter;
    }
  }, {
    key: 'uncache',
    value: function uncache(url) {
      var _this2 = this;

      return new Promise(function (resolve, reject) {
        _this2.channel.call({
          method: 'uncache',
          params: url,
          success: resolve,
          error: reject
        });
      });
    }
  }, {
    key: 'log',
    value: function log(message) {
      this.channel.notify({ method: 'log', params: message });
    }
  }, {
    key: 'error',
    value: function error(err) {
      err = typeof err === 'string' ? { message: err } : err;
      this.channel.notify({ method: 'error', params: [err.message, err.stack] });
    }
  }]);

  return KioskClient;
}();

exports.default = KioskClient;