'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _KioskClient = require('./KioskClient');

var _KioskClient2 = _interopRequireDefault(_KioskClient);

var _serviceWorkerRegistration = require('./service-worker-registration');

var _serviceWorkerRegistration2 = _interopRequireDefault(_serviceWorkerRegistration);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var kioskClient = null;
var onConnectListeners = [];

var handleKioskConnect = function handleKioskConnect(e) {
  if (e.data === 'kiosk:connect') {
    kioskClient = new _KioskClient2.default(e.source);

    onConnectListeners.forEach(function (cb) {
      return cb(kioskClient);
    });
    onConnectListeners = [];

    window.removeEventListener('message', handleKioskConnect);
  }
};

window.addEventListener('message', handleKioskConnect, false);

var Kiosk = {
  defaults: {
    swPath: 'service-worker.js',
    timeout: 250
  },

  connect: function connect(opts) {
    opts = _extends({}, Kiosk.defaults, opts);

    return new Promise(function (resolve, reject) {
      if (kioskClient) {
        resolve(kioskClient);
      } else {
        onConnectListeners.push(resolve);

        // Handle connection failure when content is not being rendered in a kiosk
        // context. Connection should happen pretty much right away so reject
        // after a short timeout.
        setTimeout(function () {
          onConnectListeners = onConnectListeners.filter(function (cb) {
            return cb !== resolve;
          });
          reject(new Error('Could not establish connection to kiosk'));
        }, opts.timeout);
      }
    });
  },
  registerServiceWorker: function registerServiceWorker(opts) {
    opts = _extends({}, Kiosk.defaults, opts);

    return Kiosk.connect(opts).then(function (kiosk) {
      return (0, _serviceWorkerRegistration2.default)({ kiosk: kiosk, path: opts.swPath });
    });
  }
};

module.exports = Kiosk;