'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

// NOTE: taken from https://github.com/GoogleChrome/sw-precache/blob/master/demo/app/js/service-worker-registration.js
exports.default = function (_ref) {
  var kiosk = _ref.kiosk;
  var path = _ref.path;

  var logInfo = function logInfo(message) {
    console.info(message);
    kiosk.log(message);
  };

  var logError = function logError(err) {
    console.error(err);
    kiosk.error(err);
  };

  if ('serviceWorker' in navigator) {
    logInfo('Fetching service worker at ' + path);

    return navigator.serviceWorker.register(path).then(function (reg) {
      logInfo('Registering service worker.');

      reg.onupdatefound = function () {
        var installingWorker = reg.installing;

        installingWorker.onstatechange = function () {
          switch (installingWorker.state) {
            case 'installed':
              if (navigator.serviceWorker.controller) {
                logInfo('New or updated content is available.');
                // TODO: this should configurable somehow based on environment
                // for non-interactive signage we want to reload right away but for
                // interactive signage or web content we want to present a new version
                // notification and ask the user to refresh. Maybe we can autoreload after
                // a few seconds of the user not interacting with the webpage but would need
                // to consider impact as this isnt standard behaviour.
                setTimeout(function () {
                  return window.location.reload();
                }, 1000);
              } else {
                logInfo('Content is now available offline!');
              }
              break;

            case 'redundant':
              logError('The installing service worker became redundant.');
              break;
          }
        };
      };
    }).catch(function (err) {
      logError(err);
    });
  }
};