import KioskClient from './KioskClient'
import registerServiceWorker from './service-worker-registration'

let kioskClient = null
let onConnectListeners = []

const handleKioskConnect = (e) => {
  if (e.data === 'kiosk:connect') {
    kioskClient = new KioskClient(e.source)

    onConnectListeners.forEach((cb) => cb(kioskClient))
    onConnectListeners = []

    window.removeEventListener('message', handleKioskConnect)
  }
}

window.addEventListener('message', handleKioskConnect, false)

const Kiosk = {
  defaults: {
    swPath: 'service-worker.js',
    timeout: 250
  },

  connect (opts) {
    opts = { ...Kiosk.defaults, ...opts }

    return new Promise((resolve, reject) => {
      if (kioskClient) {
        resolve(kioskClient)
      } else {
        onConnectListeners.push(resolve)

        // Handle connection failure when content is not being rendered in a kiosk
        // context. Connection should happen pretty much right away so reject
        // after a short timeout.
        setTimeout(() => {
          onConnectListeners = onConnectListeners.filter((cb) => cb !== resolve)
          reject(new Error('Could not establish connection to kiosk'))
        }, opts.timeout)
      }
    })
  },

  registerServiceWorker (opts) {
    opts = { ...Kiosk.defaults, ...opts }

    return Kiosk.connect(opts).then((kiosk) => {
      return registerServiceWorker({ kiosk, path: opts.swPath })
    })
  }
}

module.exports = Kiosk
