// NOTE: taken from https://github.com/GoogleChrome/sw-precache/blob/master/demo/app/js/service-worker-registration.js
export default ({ kiosk, path }) => {
  const logInfo = (message) => {
    console.info(message)
    kiosk.log(message)
  }

  const logError = (err) => {
    console.error(err)
    kiosk.error(err)
  }

  if ('serviceWorker' in navigator) {
    logInfo(`Fetching service worker at ${ path }`)

    return navigator.serviceWorker.register(path).then((reg) => {
      logInfo('Registering service worker.')

      reg.onupdatefound = () => {
        const installingWorker = reg.installing

        installingWorker.onstatechange = () => {
          switch (installingWorker.state) {
            case 'installed':
              if (navigator.serviceWorker.controller) {
                logInfo('New or updated content is available.')
                // TODO: this should configurable somehow based on environment
                // for non-interactive signage we want to reload right away but for
                // interactive signage or web content we want to present a new version
                // notification and ask the user to refresh. Maybe we can autoreload after
                // a few seconds of the user not interacting with the webpage but would need
                // to consider impact as this isnt standard behaviour.
                setTimeout(() => window.location.reload(), 1000)
              } else {
                logInfo('Content is now available offline!')
              }
              break

            case 'redundant':
              logError('The installing service worker became redundant.')
              break
          }
        }
      }
    }).catch((err) => {
      logError(err)
    })
  }
}
