import path from 'path'
import webpack from 'webpack'
import { mapValues } from 'lodash'

import envVars from './env'

export default ({ env = 'development', devServer }) => {
  const config = {}

  config.entry = {
    app: './src/index.js'
  }

  config.output = {
    filename: 'kiosk-sdk.js',
    library: 'Kiosk',
    libraryTarget: 'umd',
    path: path.resolve(__dirname, 'dist')
  }

  config.module = {
    loaders: [
      {
        test: /\.js$/,
        exclude: /build|lib|node_modules/,
        loader: 'babel'
      }
    ]
  }

  config.resolve = {
    root: [
      path.resolve(__dirname, 'src'),
      path.resolve(__dirname, 'node_modules')
    ]
  }

  config.plugins = [
    new webpack.DefinePlugin({
      'process.env': mapValues(envVars[env], (v) => JSON.stringify(v))
    })
  ]

  if (env === 'development') {
    config.devtool = 'sourcemap'
    config.debug = true
  }

  if (devServer) {
    // append dev server client to each entry
    config.entry = Object.keys(config.entry).reduce((result, key) => {
      result[key] = [
        'webpack-dev-server/client?http://localhost:' + devServer.port,
        config.entry[key]
      ]

      return result
    }, {})
  }

  if (env === 'production' || env === 'staging') {
    config.plugins = config.plugins.concat([
      new webpack.optimize.DedupePlugin(),
      new webpack.optimize.UglifyJsPlugin()
    ])
  }

  return config
}
